local _, AddonTable = ...
local ExPack = ExPack

AddonTable.ExPacks_Colors = {
	CLASSIC		= "|cFFE6CC80",
	TBC			= "|cFF1EFF00",
	WOTLK		= "|cFF66ccff",
	CATA		= "|cFFff3300",
	MOP			= "|cFF00FF96",
	WOD			= "|cFFff8C1A",
	LEGION		= "|cFFA335EE",
	BFA 		= "|cFFFF7D0A",
	SHADOWLANDS = "|cFFC0C0C0",
	DRAGONFLIGHT= "|cFFFFCC00",
}

AddonTable.majorToExpac = {
	[1]={canonName="World of Warcraft",
		shortName="WoW",
		color="|cFFE6CC80",
		},
	[2]={canonName="The Burning Crusade",
		shortName="TBC",
		color="|cFF1EFF00",
		},
	[3]={canonName="Wrath of the Lich King",
		shortName="WoLK",
		color="|cFF66ccff",
		},
	[4]={canonName="Cataclysm",
		shortName="Cata",
		color="|cFFff3300",
		},
	[5]={canonName="Mists of Pandaria",
		shortName="MoP",
		color="|cFF00FF96",
		},
	[6]={canonName="Warlords of Draenor",
		shortName="WoD",
		color="|cFFff8C1A",
		},
	[7]={canonName="Legion",
		shortName="Leg",
		color="|cFFA335EE",
		},
	[8]={canonName="Battle for Azeroth",
		shortName="BfA",
		color="|cFF494ebd",
		},
	[9]={canonName="Shadowlands",
		shortName="SL",
		color="|cFFE6CC80",
	},
	[10]={canonName="Dragonflight",
		shortName="DF",
		color="|cFFFFCC00",
	},
}

---Get the version for a given item, or nil if it does not exist in the database
---@param itemId number
---@return {major: number, minor: number, patch: number, build: number } | nil
function AddonTable.getItemVersion(itemId)
  if itemId == nil then
	ExPack:Print("empty itemId getItemVersion");
  end
  
  -- caller must ensure that itemId is a number
  local versionId = AddonTable.itemIdToVersionId[itemId]

  -- item id not found in database
  if versionId == nil then
	--ExPack:Print("getItemVersion"..itemId)
    return nil
  end

  return AddonTable.versionIdToVersion[versionId]
end

---Get the expansion for a given version (from it's major field), or nil if it does not exist in the
---database.
---@param version { major: number }
---@return {canonName:string,shortName:string}|nil asdf
function AddonTable.getVersionExpac(version)
  return AddonTable.majorToExpac[version.major]
end

---Return a dot-separated string of the components of version
---@param version {major: number, minor: number, patch: number, build: number }
---@return string
function AddonTable.buildVersionString(version)
  return format("%d.%d.%d.%d", version.major, version.minor, version.patch,
                version.build)
end

-- expose API functions
--[[
ExPack.getItemVersion = AddonTable.getItemVersion
ExPack.getVersionExpac = AddonTable.getVersionExpac
ExPack.buildVersionString = AddonTable.buildVersionString
ExPack.majorToExpac = AddonTable.majorToExpac
ExPack.itemIdToVersionId = AddonTable.itemIdToVersionId
ExPack.versionIdToVersion = AddonTable.versionIdToVersion
]]--

-- needed for access majorToExpac in Options.lua
ExPack.majorToExpac = AddonTable.majorToExpac
ExPack.getVersionExpac = AddonTable.getVersionExpac
ExPack.getItemVersion = AddonTable.getItemVersion

--ExPack:Print("ExPack_Data loaded");
