-- Using AceAddon-3.0
-- Creating an addon object
-- Including AceConsole functionality; "AceConsole-3.0"
-- Including AceEvent functionality; "AceEvent-3.0"
-- Including AceHook functionality; "AceHook-3.0"
ExPack = LibStub("AceAddon-3.0"):NewAddon("ExPack", "AceEvent-3.0", "AceConsole-3.0", "AceHook-3.0");
-- Using translations
local L = LibStub("AceLocale-3.0"):GetLocale("ExPack", "enUS", true);
-- Registering the options
local AceConfig = LibStub("AceConfigDialog-3.0");
local myAddonName = "ExPack";
local version = "v0.3.3";

ExPack.guildBank = {}
ExPack._bagUpdateDebounce = nil

function ExPack:OnInitialize()
	-- Code that you want to run when the addon is first loaded goes here.
	--ExPack:dPrint("Begin ExPack")

	-- Using AceConsole for slash commands
	--ExPack:RegisterChatCommand( "expack", "ChatCommand" );
	--ExPack:dPrint("AceConsole")
	ExPack:RegisterChatCommand( "ep", "ChatCommand" );

	--Using AceDB-3.0
	-- SavedVariables already prepared in toc file
	-- Initializing AceDB
	--ExPack:dPrint("AceDB")
	self.db = LibStub("AceDB-3.0"):New("Ghordian_ExPackDB", ExPack.defaults)
	-- Working with profiles
	if (self.db.profile == nil) or not (self.db.profile) then 
		self.db.profile = ExPack.defaults.profile; 
	end;

	-- Registering the options
	--ExPack:Print("AceConfig")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("ExPack", ExPack.options);
	AceConfig:AddToBlizOptions("ExPack", "ExPack");

	-- Standard hooking
	--ExPack:dPrint("AceHook")
	--[[ SIMPLIFIED BY ContainerFrame_GenerateFrame
	ExPack:SecureHook("OpenAllBags", "ExPack_OpenAllBags");
	ExPack:SecureHook("ToggleAllBags", "ExPack_ToggleAllBags");
	ExPack:SecureHook("ToggleBag", "ExPack_ToggleBag");
	ExPack:SecureHook("OpenBag", "ExPack_OpenBag");
	]]--
	ExPack:SecureHook(C_Container, "PickupContainerItem", "ExPack_PickupContainerItem");
	
	ExPack:SecureHook("BankFrameItemButton_Update", "ExPack_BankFrameItemButton_Update");
	
	if _G.ContainerFrame_Update then
		ExPack:SecureHook("ContainerFrame_Update", "ExPack_ContainerFrame_Update");
	else
		ExPack:SecureHook("ContainerFrame_GenerateFrame", ExPack_ContainerFrame_GenerateFrame)
	end
	
	if Bagnon and BagnonFrameinventory then
		BagnonFrameinventory:HookScript('onShow', function()
			ExPack:ExPack_BagnonFrameinventory()
		end)
	end

	--ExPack:dPrint("AceEvent")
	if (ExPack:CheckDB() == true) then
		-- Including AceEvent functionality
		ExPack:RegEvents();
	end;

	-- Using AceConsole for output; used as a mixin for AceAddon
	ExPack:Print("ExPack by |cff69CCF0Ghordian");
end

function ExPack:OnEnable()
	ExPack:Print("OnEnable |cff00CC00LOADED");
    -- Called when the addon is enabled
	ExPack:RegEvents();
end

function ExPack:OnDisable()
	ExPack:Print("OnDisable |cff00CC00LOADED");
    -- Called when the addon is disabled
	ExPack:UnRegEvents();
end

function ExPack:ChatCommand(input)
	-- Process the slash command ('input' contains whatever follows the slash command)
	-- first time opens Interfaz Frame
	InterfaceOptionsFrame_OpenToCategory("ExPack");
	-- Second time opens Category Option Panel
	InterfaceOptionsFrame_OpenToCategory("ExPack");
end;

function ExPack:CheckDB()
	if self.db.profile.UseLibItemInfo then 	
		local LII = LibStub("LibItemInfo-1.0");
		if LII == nil then
			if self.db.profile.ErrorReporting then
				ExPack:Print("LibItemInfo |cffCC0000NOT LOADED");
			else
				ExPack:Print("LibItemInfo |cff00CC00LOADED");
			end
			return false;
		end
	else
		if not (ExPack.itemIdToVersionId) then return false; end;
		if not (ExPack.versionIdToVersion) then return false; end;
	end
	return true;
end;

function ExPack:RegEvents()
	-- Subscribing to events
	--ExPack:dPrint("RegEvents")
	-- ExPack:RegisterEvent("NAME_OF_EVENT")
	
	-- Events for Guild Bank UI Dragonflight 10.0.02
	--REMOVED ExPack:RegisterEvent("GUILDBANKFRAME_OPENED")
	--REMOVED ExPack:RegisterEvent("GUILDBANKFRAME_CLOSED") 
	ExPack:RegisterEvent("GUILDBANKBAGSLOTS_CHANGED")
	
	-- Events for Player bank UI
	ExPack:RegisterEvent("BANKFRAME_OPENED")
	ExPack:RegisterEvent("PLAYERREAGENTBANKSLOTS_CHANGED")
end

function ExPack:UnRegEvents()
	--REMOVED ExPack:UnregisterEvent("GUILDBANKFRAME_OPENED")

	-- Events for Player bank UI
	ExPack:UnregisterEvent("BANKFRAME_OPENED")
	ExPack:UnregisterEvent("PLAYERREAGENTBANKSLOTS_CHANGED")
end

--[[
function ExPack:GUILDBANKFRAME_OPENED()
	--if not self.db.profile.Enabled then return end
	ExPack:dPrint("OnGuildBankFrameOpened")

	ExPack.guildBank.isGuildBankOpen = true
	ExPack.guildBank.numTabs = GetNumGuildBankTabs()
	ExPack.guildBank.guildFunds = GetGuildBankMoney()
	ExPack.guildBank.tab = GetCurrentGuildBankTab()

	--register the _CLOSED event whenever the bank is opened
	--REMOVED ExPack:RegisterEvent("GUILDBANKFRAME_CLOSED") 
	--REDO ExPack:RegisterEvent("GUILDBANKBAGSLOTS_CHANGED")
end

function ExPack:GUILDBANKFRAME_CLOSED() 
	--if not self.db.profile.Enabled then return end
	ExPack:dPrint("OnGuildBankFrameClosed")

	--REMOVED ExPack:UnregisterEvent("GUILDBANKFRAME_CLOSED") 
	ExPack:UnregisterEvent("GUILDBANKBAGSLOTS_CHANGED")

	ExPack:GuildBankFrame_RemoveExPack();
end
]]--

function ExPack:GUILDBANKBAGSLOTS_CHANGED() 
	ExPack.guildBank.isGuildBankOpen = true
	--if not self.db.profile.Enabled then return end
	ExPack:dPrint("GUILDBANKBAGSLOTS_CHANGED");
	ExPack_Debounce(ExPack_OnGuildBankFrameChanged, 0.01)
end

function ExPack_OnGuildBankFrameChanged() 
	if not ExPack.db.profile.Enabled then return end
	if ExPack.guildBank.isGuildBankVisited == false then
		ExPack.guildBank.isGuildBankVisited = true
	end
	ExPack:dPrint("OnGuildBankFrameChanged")
	local num, itemString
	if (GuildBankFrame and GuildBankFrame:IsVisible())
		or (BagnonFrameguildbank and BagnonFrameguildbank:IsVisible()) then
		local tab = GetCurrentGuildBankTab();
		if ( ExPack.guildBank.tab ~= tab ) then
			if (tab ~= nil) and (ExPack.guildBank.tab ~= nil) then
				--ExPack:jPrint("GuildBankFrame.Tab differ; "..tab.."; "..ExPack.guildBank.tab);
			end
			ExPack:GuildBankFrame_RemoveExPack();
		end
		ExPack.guildBank.tab = tab;

		-- GuildBankFrame_OnLoad(..)
		-- GuildBankFrame.mode == "bank"
		local button, index, column;
		local NumSlotsPerGuildBankGroup = 14 --NUM_SLOTS_PER_GUILDBANK_GROUP;
		local btnCount = 0
		local thisContainer = ContainerTypes[ExPack.Types.GUILDBANK]
		local size = thisContainer:GetSize();
		ExPack:dPrint("GuildBankSize; "..size.."; "..NumSlotsPerGuildBankGroup)
		for slot=1, size do
			index = mod(slot, NumSlotsPerGuildBankGroup);
			if ( index == 0 ) then
				index = NumSlotsPerGuildBankGroup;
			end
			column = ceil((slot-0.5) / NumSlotsPerGuildBankGroup);
			--ExPack:jPrint("GuildBankColumn; tab; "..tab.."; slot; "..slot.."; column"..column.."; index; "..index);
			button = _G["GuildBankColumn"..column.."Button"..index];
			if button == nil then
			--	ExPack:dPrint("GuildBankColumn fail")
				button = GuildBankFrame.Columns[column].Buttons[index];
			end
			if button ~= nil then
				ExPack:ScanBagFrame(tab, slot, button, thisContainer);
				btnCount = btnCount + 1
			else
				ExPack:dPrint("GuildBankFrame fail")
			end
		end
		if ( btnCount < size ) then
			ExPack:jPrint("GuildBankColumn; "..btnCount.."; "..size);
		end
		ExPack:dReset();
	else
		ExPack:dPrint("No GuildBankFrame; ");
	end
	ExPack.guildBank.isGuildBankOpen = false
end

function ExPack:BANKFRAME_OPENED()
	if not self.db.profile.Enabled then return end
	ExPack:dPrint("OnBankFrameOpened");

	local frame = BankFrame;
	if (frame.activeTabIndex == 1) then
		for bagID = NUM_BAG_SLOTS + 1, NUM_BAG_SLOTS + NUM_BANKBAGSLOTS do		-- 5 to 11
			ExPack:ScanBag(bagID)
		end
		--ExPack:ScanBank();
	elseif (frame.activeTabIndex == 2) then
		ExPack:ScanReagentBank();
	end

	ExPack:RegisterEvent("BANKFRAME_CLOSED")
	ExPack:RegisterEvent("PLAYERBANKSLOTS_CHANGED")
	ExPack:RegisterEvent("REAGENTBANK_UPDATE")
	ExPack:RegisterEvent("PLAYERREAGENTBANKSLOTS_CHANGED")
end

function ExPack:BANKFRAME_CLOSED()
	if not self.db.profile.Enabled then return end
	--
	ExPack:dPrint("OnBankFrameClosed")
	
	ExPack:UnregisterEvent("BANKFRAME_CLOSED")
	ExPack:UnregisterEvent("PLAYERBANKSLOTS_CHANGED")

	-- done ; clean after close
	ExPack:BankFrame_RemoveExPack();
end

function ExPack:PLAYERBANKSLOTS_CHANGED(slot)
	if not self.db.profile.Enabled then return end
	--
	ExPack:dPrint("OnPlayerBankSlotsChanged; "..slot)
	ExPack:dReset()

	ExPack:ScanContainer(BANK_CONTAINER, ExPack.Types.BANK)
end

function ExPack:REAGENTBANK_UPDATE()
	if not self.db.profile.Enabled then return end
	ExPack:dPrint("ReagentbankUpdate")

	ExPack:ScanReagentBank()
end

function ExPack:PLAYERREAGENTBANKSLOTS_CHANGED(slot)
	if not self.db.profile.Enabled then return end
	ExPack:dPrint("OnReagentBankFrameChanged; "..slot)

	ExPack:ScanReagentBank()
end

function ExPack:BAG_UPDATE(event)
	ExPack:dPrint("BAG_UPDATE; ");
	--if not self.db.profile.Enabled then return end
	--
	ExPack:ExPack_BagsUpdate(event);
end

function ExPack_OnEvent(self, event, ...)
    if ((event == "BAG_UPDATE") or (event == "BAG_CONTAINER_UPDATE")) then
        ExPack_Debounce(ExPack_ExecuteButtonUpdates, 0.01)
    elseif (event == "GUILDBANKBAGSLOTS_CHANGED") then
        ExPack_Debounce(ExPack_ExecuteButtonUpdatesGuildBank, 0.01)
    else
        --print(self, event, ...)
		ExPack:dPrint("ExPack_OnEvent; ");
    end
end

function ExPack_Debounce(fn, seconds)
    if (ExPack._bagUpdateDebounce) then
        ExPack._bagUpdateDebounce.cancelled = true
    end

    local timer = {
        func = fn,
        cancelled = false,
    }

    timer.callback = function()
        if not timer.cancelled then
            timer.func()
            ExPack._bagUpdateDebounce = nil
        end
    end

    ExPack._bagUpdateDebounce = timer
    C_Timer.After(seconds, timer.callback)
    gTimer = timer
end

function ExPack_OnLoad(self, event)
	ExPack:dPrint("ExPack_OnLoad; ");
end

function ExPack_ExecuteButtonUpdates()
	ExPack:dPrint("ExPack_ExecuteButtonUpdates; ");
end

function ExPack_ExecuteButtonUpdatesGuildBank()
	ExPack:dPrint("ExPack_ExecuteButtonUpdatesGuildBank; ");
end

function ExPack_CloseGuildBankFrame()
	ExPack:dPrint("ExPack_CloseGuildBankFrame; ");
	ExPack:BANKFRAME_CLOSED()
end
